##  Prerequisites
  * Relation mappings require existing fact sheet mappings. The relation endpoints must reference previously configured fact sheet mappings. Complete at least two fact sheet mapping configurations as described in [Fact Sheet Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Define which fact sheets and attributes to synchronize between Jira Service Management and SAP LeanIX.").
  * Identify which relations between fact sheets you want to synchronize.
  * Determine the source for each relation.
